@@ -33,3 +33,12 @@ from .predicates import (
 )
 from .qualification import Qualification
 from .security_filter import list_security_filters, SecurityFilter
+from ...utils import helper
+
+
+helper.deprecation_warning(
+     deprecated='`mstrio.access_and_security.security_filter`',
+     new='`mstrio.modeling.security_filter` and `mstrio.modeling.expression`',
+     version='11.3.7.103',  # NOSONAR
+     module=False
+ )
