@@ -20,8 +20,9 @@ ISERVER_VERSION_11_3_2 = '11.3.0200'
 
 
 @ErrorHandler(err_msg='Error getting list of all projects from metadata.')
-def get_projects(connection: "Connection", offset: int = 0, limit: int = -1,
-                 error_msg: str = None):
+def get_projects(
+    connection: "Connection", offset: int = 0, limit: int = -1, error_msg: str = None
+):
     """Get list of all projects from metadata.
     Args:
         connection(object): MicroStrategy connection object returned by
@@ -41,14 +42,18 @@ def get_projects(connection: "Connection", offset: int = 0, limit: int = -1,
         url=f'{connection.base_url}/api/monitors/projects',
         headers={'X-MSTR-ProjectID': None},
         params={
-            'offset': offset,
-            'limit': limit
+            'offset': offset, 'limit': limit
         },
     )
 
 
-def get_projects_async(future_session: "FuturesSession", connection: "Connection", offset: int = 0,
-                       limit: int = -1, error_msg: str = None):
+def get_projects_async(
+    future_session: "FuturesSession",
+    connection: "Connection",
+    offset: int = 0,
+    limit: int = -1,
+    error_msg: str = None
+):
     """Get list of all projects from metadata asynchronously.
     Args:
         connection(object): MicroStrategy connection object returned by
@@ -71,9 +76,11 @@ def get_projects_async(future_session: "FuturesSession", connection: "Connection
 
 
 @ErrorHandler(
-    err_msg='Error getting information about nodes in the connected Intelligence Server cluster.')
-def get_node_info(connection: "Connection", id: str = None, node_name: str = None,
-                  error_msg: str = None):
+    err_msg='Error getting information about nodes in the connected Intelligence Server cluster.'
+)
+def get_node_info(
+    connection: "Connection", id: str = None, node_name: str = None, error_msg: str = None
+):
     """Get information about nodes in the connected Intelligence Server
     cluster.
 
@@ -91,16 +98,22 @@ def get_node_info(connection: "Connection", id: str = None, node_name: str = Non
         url=f'{connection.base_url}/api/monitors/iServer/nodes',
         headers={'X-MSTR-ProjectID': None},
         params={
-            'projects.id': id,
-            'name': node_name
+            'projects.id': id, 'name': node_name
         },
     )
 
 
 @ErrorHandler(
-    err_msg='Error updating properties for a project {project_id} for cluster node {node_name}.')
-def update_node_properties(connection: "Connection", node_name: str, project_id: str, body: dict,
-                           error_msg: str = None, whitelist: Optional[List[tuple]] = None):
+    err_msg='Error updating properties for a project {project_id} for cluster node {node_name}.'
+)
+def update_node_properties(
+    connection: "Connection",
+    node_name: str,
+    project_id: str,
+    body: dict,
+    error_msg: str = None,
+    whitelist: Optional[List[tuple]] = None
+):
     """Update properties such as project status for a specific project for
     respective cluster node. You obtain cluster node name and project id from
     GET /monitors/iServer/nodes.
@@ -138,8 +151,12 @@ def update_node_properties(connection: "Connection", node_name: str, project_id:
 
 
 @ErrorHandler(err_msg='Error adding node {node_name} to connected Intelligence Server cluster.')
-def add_node(connection: "Connection", node_name: str, error_msg: str = None,
-             whitelist: Optional[List[tuple]] = None):
+def add_node(
+    connection: "Connection",
+    node_name: str,
+    error_msg: str = None,
+    whitelist: Optional[List[tuple]] = None
+):
     """Add a node to the connected Intelligence Server cluster. The node must
     meet I-Server clustering requirements. If the node is part of a multi-node
     cluster, all the nodes in that cluster will be added. If the node is
@@ -167,9 +184,14 @@ def add_node(connection: "Connection", node_name: str, error_msg: str = None,
 
 
 @ErrorHandler(
-    err_msg='Error removing node {node_name} from the connected Intelligence Server cluster.')
-def remove_node(connection: "Connection", node_name: str, error_msg: str = None,
-                whitelist: Optional[List[tuple]] = None):
+    err_msg='Error removing node {node_name} from the connected Intelligence Server cluster.'
+)
+def remove_node(
+    connection: "Connection",
+    node_name: str,
+    error_msg: str = None,
+    whitelist: Optional[List[tuple]] = None
+):
     """Remove a node from the connected Intelligence Server cluster. After a
     successful removal, some existing authorization tokens may become
     invalidated and in this case re-login is needed. You cannot remove a node
@@ -197,8 +219,13 @@ def remove_node(connection: "Connection", node_name: str, error_msg: str = None,
 
 
 @ErrorHandler(err_msg='Error getting user connections for {node_name} cluster node.')
-def get_user_connections(connection: "Connection", node_name: str, offset: int = 0,
-                         limit: int = 100, error_msg: str = None):
+def get_user_connections(
+    connection: "Connection",
+    node_name: str,
+    offset: int = 0,
+    limit: int = 100,
+    error_msg: str = None
+):
     """Get user connections information on specific intelligence server node.
 
     Args:
@@ -219,15 +246,18 @@ def get_user_connections(connection: "Connection", node_name: str, offset: int =
         url=f'{connection.base_url}/api/monitors/userConnections',
         headers={'X-MSTR-ProjectID': None},
         params={
-            'clusterNode': node_name,
-            'offset': offset,
-            'limit': limit
+            'clusterNode': node_name, 'offset': offset, 'limit': limit
         },
     )
 
 
-def get_user_connections_async(future_session: "FuturesSession", connection: "Connection",
-                               node_name: str, offset: int = 0, limit: int = 100):
+def get_user_connections_async(
+    future_session: "FuturesSession",
+    connection: "Connection",
+    node_name: str,
+    offset: int = 0,
+    limit: int = 100
+):
     """Get user connections information on specific intelligence server node.
 
     Args:
@@ -250,8 +280,9 @@ def get_user_connections_async(future_session: "FuturesSession", connection: "Co
     return future
 
 
-def delete_user_connection(connection: "Connection", id: str, error_msg: str = None,
-                           bulk: bool = False):
+def delete_user_connection(
+    connection: "Connection", id: str, error_msg: str = None, bulk: bool = False
+):
     """Disconnect a user connection on specific intelligence server node.
 
     Args:
@@ -274,8 +305,9 @@ def delete_user_connection(connection: "Connection", id: str, error_msg: str = N
     return response
 
 
-def delete_user_connection_async(future_session: "FuturesSession", connection: "Connection",
-                                 id: str, error_msg: str = None):
+def delete_user_connection_async(
+    future_session: "FuturesSession", connection: "Connection", id: str, error_msg: str = None
+):
     """Disconnect a user connection on specific intelligence server node.
 
     Args:
@@ -342,8 +374,13 @@ def delete_cube_cache(connection: "Connection", id: str, throw_error: bool = Tru
 
 
 @ErrorHandler(err_msg='Error altering cube cache {id} status.')
-def alter_cube_cache_status(connection: "Connection", id: str, active: bool = None,
-                            loaded: bool = None, throw_error: bool = True):
+def alter_cube_cache_status(
+    connection: "Connection",
+    id: str,
+    active: bool = None,
+    loaded: bool = None,
+    throw_error: bool = True
+):
     """Alter an cube cache status. In one request it is possible to set either
     'active' or 'loaded', never both.
 
@@ -365,14 +402,24 @@ def alter_cube_cache_status(connection: "Connection", id: str, active: bool = No
     body = {'state': {'active': active, 'loadedState': loaded}}
     body = delete_none_values(body, recursion=True)
 
-    return connection.patch(url=f'{connection.base_url}/api/monitors/caches/cubes/{id}',
-                            headers={'Prefer': 'respond-async'}, json=body)
+    return connection.patch(
+        url=f'{connection.base_url}/api/monitors/caches/cubes/{id}',
+        headers={'Prefer': 'respond-async'},
+        json=body
+    )
 
 
 @ErrorHandler(err_msg='Error getting list of cube caches for node {node}.')
-def get_cube_caches(connection: "Connection", node: str, offset: int = 0, limit: int = 1000,
-                    project_ids: str = None, loaded: bool = False, sort_by: str = None,
-                    error_msg: str = None):
+def get_cube_caches(
+    connection: "Connection",
+    node: str,
+    offset: int = 0,
+    limit: int = 1000,
+    project_ids: str = None,
+    loaded: bool = False,
+    sort_by: str = None,
+    error_msg: str = None
+):
     """Get the list of cube caches on a specific cluster node.
 
     Args:
@@ -411,9 +458,16 @@ def get_cube_caches(connection: "Connection", node: str, offset: int = 0, limit:
     )
 
 
-def get_cube_caches_async(future_session: "FuturesSession", connection: "Connection", node: str,
-                          offset: int = 0, limit: int = 1000, project_ids: str = None,
-                          loaded: bool = False, sort_by: str = None):
+def get_cube_caches_async(
+    future_session: "FuturesSession",
+    connection: "Connection",
+    node: str,
+    offset: int = 0,
+    limit: int = 1000,
+    project_ids: str = None,
+    loaded: bool = False,
+    sort_by: str = None
+):
     """Get the list of cube caches on a specific cluster node asynchronously.
 
     Args:
@@ -453,8 +507,9 @@ def get_cube_caches_async(future_session: "FuturesSession", connection: "Connect
 
 
 @ErrorHandler(err_msg='Error getting cube cache manipulation {manipulation_id} status.')
-def get_cube_cache_manipulation_status(connection: "Connection", manipulation_id: str,
-                                       throw_error: bool = True):
+def get_cube_cache_manipulation_status(
+    connection: "Connection", manipulation_id: str, throw_error: bool = True
+):
     """Get the manipulation status of cube cache.
 
     Args:
@@ -491,8 +546,9 @@ def get_database_connections(connection: "Connection", nodes_names: str, error_m
 
 
 @ErrorHandler(err_msg='Error deleting database connections {connection_id}.')
-def delete_database_connection(connection: "Connection", connection_id: str,
-                               error_msg: str = None):
+def delete_database_connection(
+    connection: "Connection", connection_id: str, error_msg: str = None
+):
     """Disconnect a database connection on specific intelligence server node.
 
     Args:
@@ -505,8 +561,9 @@ def delete_database_connection(connection: "Connection", connection_id: str,
     return connection.delete(url=url)
 
 
-def delete_database_connection_async(future_session: "FuturesSession", connection: "Connection",
-                                     connection_id: str):
+def delete_database_connection_async(
+    future_session: "FuturesSession", connection: "Connection", connection_id: str
+):
     """Disconnect a database connection on specific intelligence server node.
 
     Args:
@@ -521,8 +578,13 @@ def delete_database_connection_async(future_session: "FuturesSession", connectio
     return future_session.delete(url=url)
 
 
-def get_job(connection: "Connection", id: str, node_name: str = None, fields: List[str] = None,
-            error_msg: str = None):
+def get_job(
+    connection: "Connection",
+    id: str,
+    node_name: str = None,
+    fields: List[str] = None,
+    error_msg: str = None
+):
     """Get job information.
 
     Args:
@@ -599,9 +661,18 @@ def get_job_v2(connection: "Connection", id: str, fields: List[str] = None, erro
 
 
 @ErrorHandler(err_msg="Error getting jobs list.")
-def get_jobs(connection: "Connection", node_name: str, project_id: str = None, status: str = None,
-             job_type: str = None, user_full_name: str = None, object_id: str = None,
-             sort_by: str = None, fields: List[str] = None, error_msg: str = None) -> Response:
+def get_jobs(
+    connection: "Connection",
+    node_name: str,
+    project_id: str = None,
+    status: str = None,
+    job_type: str = None,
+    user_full_name: str = None,
+    object_id: str = None,
+    sort_by: str = None,
+    fields: List[str] = None,
+    error_msg: str = None
+) -> Response:
     """Get list of a jobs.
 
     Args:
@@ -637,10 +708,19 @@ def get_jobs(connection: "Connection", node_name: str, project_id: str = None, s
     return connection.get(url)
 
 
-def get_jobs_async(future_session: "FuturesSession", connection: "Connection", node_name: str,
-                   project_id: str = None, status: str = None, job_type: str = None,
-                   user_full_name: str = None, object_id: str = None, sort_by: str = None,
-                   fields: List[str] = None, error_msg: str = None) -> Response:
+def get_jobs_async(
+    future_session: "FuturesSession",
+    connection: "Connection",
+    node_name: str,
+    project_id: str = None,
+    status: str = None,
+    job_type: str = None,
+    user_full_name: str = None,
+    object_id: str = None,
+    sort_by: str = None,
+    fields: List[str] = None,
+    error_msg: str = None
+) -> Response:
     """Get list of a jobs asynchronously.
 
     Args:
@@ -679,17 +759,26 @@ def get_jobs_async(future_session: "FuturesSession", connection: "Connection", n
 
 
 @ErrorHandler(err_msg="Error getting jobs list")
-def get_jobs_v2(connection: "Connection", node_name: str, user: Union[List[str], str] = None,
-                description: str = None, type: Union[List[str], str] = None,
-                status: Union[List[str], str] = None, object_id: Optional[List[str]] = None,
-                object_type: Union[List[str], str] = None, project_id: Union[List[str],
-                                                                             str] = None,
-                project_name: Union[List[str], str] = None, pu_name: Union[List[str], str] = None,
-                subscription_type: Union[List[str],
-                                         str] = None, subscription_recipient: Union[List[str],
-                                                                                    str] = None,
-                memory_usage: str = None, elapsed_time: str = None, sort_by: str = None,
-                fields: List[str] = None, error_msg: str = None):
+def get_jobs_v2(
+    connection: "Connection",
+    node_name: str,
+    user: Union[List[str], str] = None,
+    description: str = None,
+    type: Union[List[str], str] = None,
+    status: Union[List[str], str] = None,
+    object_id: Optional[List[str]] = None,
+    object_type: Union[List[str], str] = None,
+    project_id: Union[List[str], str] = None,
+    project_name: Union[List[str], str] = None,
+    pu_name: Union[List[str], str] = None,
+    subscription_type: Union[List[str], str] = None,
+    subscription_recipient: Union[List[str], str] = None,
+    memory_usage: str = None,
+    elapsed_time: str = None,
+    sort_by: str = None,
+    fields: List[str] = None,
+    error_msg: str = None
+):
     """Get list of a jobs.
 
     Args:
@@ -760,18 +849,27 @@ def get_jobs_v2(connection: "Connection", node_name: str, user: Union[List[str],
     return connection.get(url)
 
 
-def get_jobs_v2_async(future_session: "FuturesSession", connection: "Connection", node_name: str,
-                      user: Union[List[str], str] = None, description: str = None,
-                      type: Union[List[str], str] = None, status: Union[List[str], str] = None,
-                      object_id: Optional[List[str]] = None, object_type: Union[List[str],
-                                                                                str] = None,
-                      project_id: Union[List[str], str] = None, project_name: Union[List[str],
-                                                                                    str] = None,
-                      pu_name: Union[List[str], str] = None, subscription_type: Union[List[str],
-                                                                                      str] = None,
-                      subscription_recipient: Union[List[str], str] = None,
-                      memory_usage: str = None, elapsed_time: str = None, sort_by: str = None,
-                      fields: List[str] = None, error_msg: str = None) -> Response:
+def get_jobs_v2_async(
+    future_session: "FuturesSession",
+    connection: "Connection",
+    node_name: str,
+    user: Union[List[str], str] = None,
+    description: str = None,
+    type: Union[List[str], str] = None,
+    status: Union[List[str], str] = None,
+    object_id: Optional[List[str]] = None,
+    object_type: Union[List[str], str] = None,
+    project_id: Union[List[str], str] = None,
+    project_name: Union[List[str], str] = None,
+    pu_name: Union[List[str], str] = None,
+    subscription_type: Union[List[str], str] = None,
+    subscription_recipient: Union[List[str], str] = None,
+    memory_usage: str = None,
+    elapsed_time: str = None,
+    sort_by: str = None,
+    fields: List[str] = None,
+    error_msg: str = None
+) -> Response:
     """Get list of a jobs asynchronously.
 
     Args:
@@ -867,8 +965,9 @@ def cancel_job(connection: "Connection", id: str, fields: List[str] = None, erro
 
 
 @ErrorHandler(err_msg="Error killing job {id}")
-def cancel_job_v1(connection: "Connection", id: str, fields: List[str] = None,
-                  error_msg: str = None):
+def cancel_job_v1(
+    connection: "Connection", id: str, fields: List[str] = None, error_msg: str = None
+):
     """Cancel a job specified by `id`.
 
     Args:
@@ -887,8 +986,9 @@ def cancel_job_v1(connection: "Connection", id: str, fields: List[str] = None,
 
 
 @ErrorHandler(err_msg="Error killing job {id}")
-def cancel_job_v2(connection: "Connection", id: str, fields: List[str] = None,
-                  error_msg: str = None):
+def cancel_job_v2(
+    connection: "Connection", id: str, fields: List[str] = None, error_msg: str = None
+):
     """Cancel a job specified by `id`.
 
     Args:
@@ -906,8 +1006,9 @@ def cancel_job_v2(connection: "Connection", id: str, fields: List[str] = None,
     return connection.delete(url=f'{connection.base_url}/api/v2/monitors/jobs/{id}', params=params)
 
 
-def cancel_jobs(connection: "Connection", ids: List[str], fields: List[str] = None,
-                error_msg: str = None) -> Union[Success, PartialSuccess, MstrException]:
+def cancel_jobs(
+    connection: "Connection", ids: List[str], fields: List[str] = None, error_msg: str = None
+) -> Union[Success, PartialSuccess, MstrException]:
     """Cancel jobs specified by `ids`. Use cancel_jobs_v1 if I-Server version
     is 11.3.2 or cancel_jobs_v2 otherwise.
 
@@ -931,8 +1032,9 @@ def cancel_jobs(connection: "Connection", ids: List[str], fields: List[str] = No
     return bulk_operation_response_handler(response, "jobCancellationStatus")
 
 
-def cancel_jobs_v1(connection: "Connection", ids: List[str], fields: List[str] = None,
-                   error_msg: str = None):
+def cancel_jobs_v1(
+    connection: "Connection", ids: List[str], fields: List[str] = None, error_msg: str = None
+):
     """Cancel jobs specified by `ids`.
 
     Args:
@@ -949,14 +1051,16 @@ def cancel_jobs_v1(connection: "Connection", ids: List[str], fields: List[str] =
 
     if ids:
         body = {'jobIds': ids}
-        return connection.post(url=f'{connection.base_url}/api/monitors/cancelJobs', params=params,
-                               json=body)
+        return connection.post(
+            url=f'{connection.base_url}/api/monitors/cancelJobs', params=params, json=body
+        )
     else:
         raise ValueError("No ids have been passed.")
 
 
-def cancel_jobs_v2(connection: "Connection", ids: List[str], fields: List[str] = None,
-                   error_msg: str = None):
+def cancel_jobs_v2(
+    connection: "Connection", ids: List[str], fields: List[str] = None, error_msg: str = None
+):
     """Cancel jobs specified by `ids`.
 
     Args:
@@ -973,7 +1077,8 @@ def cancel_jobs_v2(connection: "Connection", ids: List[str], fields: List[str] =
 
     if ids:
         body = {'jobIds': ids}
-        return connection.post(url=f'{connection.base_url}/api/v2/monitors/cancelJobs',
-                               params=params, json=body)
+        return connection.post(
+            url=f'{connection.base_url}/api/v2/monitors/cancelJobs', params=params, json=body
+        )
     else:
         raise ValueError("No ids have been passed.")
