@@ -3,13 +3,16 @@ from typing import List, TYPE_CHECKING, Union
 from mstrio.api import datasources
 from mstrio.utils import helper
 from mstrio.utils.entity import EntityBase, ObjectTypes
+from mstrio.utils.version_helper import class_version_handler, method_version_handler
 
 if TYPE_CHECKING:
     from mstrio.connection import Connection
 
 
-def list_available_dbms(connection: "Connection", to_dictionary: bool = False, limit: int = None,
-                        **filters) -> Union[List["Dbms"], List[dict]]:
+@method_version_handler('11.3.0000')
+def list_available_dbms(
+    connection: "Connection", to_dictionary: bool = False, limit: int = None, **filters
+) -> Union[List["Dbms"], List[dict]]:
     """List all available database management systems (DBMSs) objects or dicts.
     Optionally filter the DBMS by specifying filters.
 
@@ -34,6 +37,7 @@ def list_available_dbms(connection: "Connection", to_dictionary: bool = False, l
     )
 
 
+@class_version_handler('11.3.0000')
 class Dbms(EntityBase):
     """Object representation of MicroStrategy Database management system (DBMS)
 
@@ -48,21 +52,32 @@ class Dbms(EntityBase):
     _FROM_DICT_MAP = {}  # map attributes to Enums and Composites
     _DBMS_CACHE = set()
 
-    def __init__(self, connection: "Connection", name: str = None, id: str = None,
-                 type: str = None, version: str = None):
+    def __init__(
+        self,
+        connection: "Connection",
+        name: str = None,
+        id: str = None,
+        type: str = None,
+        version: str = None
+    ):
         """Initialize Dbms object."""
         if name is None and id is None:
             helper.exception_handler(
                 "Please specify either 'name' or 'id' parameter in the constructor.",
-                exception_type=ValueError)
+                exception_type=ValueError
+            )
         temp_dbms = None
 
         for dbms in self._DBMS_CACHE:
             if name == dbms.name or id == dbms.id:
                 temp_dbms = dbms
-                super().__init__(connection=connection, object_id=temp_dbms.id,
-                                 name=temp_dbms.name, type=temp_dbms.type,
-                                 version=temp_dbms.version)
+                super().__init__(
+                    connection=connection,
+                    object_id=temp_dbms.id,
+                    name=temp_dbms.name,
+                    type=temp_dbms.type,
+                    version=temp_dbms.version
+                )
 
         if not temp_dbms:
             if id:
@@ -72,9 +87,13 @@ class Dbms(EntityBase):
 
             if temp_dbms:
                 [temp_dbms] = temp_dbms
-                super().__init__(connection=connection, object_id=temp_dbms["id"],
-                                 name=temp_dbms["name"], type=temp_dbms["type"],
-                                 version=temp_dbms["version"])
+                super().__init__(
+                    connection=connection,
+                    object_id=temp_dbms["id"],
+                    name=temp_dbms["name"],
+                    type=temp_dbms["type"],
+                    version=temp_dbms["version"]
+                )
             else:
                 identifier = name if name else id
                 raise ValueError(f"There is no Dbms: '{identifier}'")
@@ -85,13 +104,16 @@ class Dbms(EntityBase):
         self._version = kwargs.get("version")
 
     @classmethod
-    def _list_available_dbms(cls, connection: "Connection", to_dictionary: bool = False,
-                             limit: int = None, **filters) -> Union[List["Dbms"], List[dict]]:
+    def _list_available_dbms(
+        cls, connection: "Connection", to_dictionary: bool = False, limit: int = None, **filters
+    ) -> Union[List["Dbms"], List[dict]]:
 
-        objects = helper.fetch_objects(connection=connection, api=datasources.get_available_dbms,
-                                       limit=None, filters=None)
+        objects = helper.fetch_objects(
+            connection=connection, api=datasources.get_available_dbms, limit=None, filters=None
+        )
         cls._DBMS_CACHE.update(
-            [cls.from_dict(source=obj, connection=connection) for obj in objects])
+            [cls.from_dict(source=obj, connection=connection) for obj in objects]
+        )
 
         if limit:
             objects = objects[:limit]
