@@ -95,8 +95,14 @@ class FileSystem(Dictable):
         append_to_file: Whether to append to the file, default: False
     """
     _DELETE_NONE_VALUES_RECURSION = False
-    def __init__(self, create_folder: bool = True, filename_append_time_stamp: bool = True,
-                 override_filename: bool = False, append_to_file: bool = False):
+
+    def __init__(
+        self,
+        create_folder: bool = True,
+        filename_append_time_stamp: bool = True,
+        override_filename: bool = False,
+        append_to_file: bool = False
+    ):
         self.create_folder = create_folder
         self.filename_append_time_stamp = filename_append_time_stamp
         self.override_filename = override_filename
@@ -112,8 +118,13 @@ class ConnectionParameters(Dictable):
         delivery_timeout_seconds: Delivery Timeout (Seconds), default: 10
     """
     _DELETE_NONE_VALUES_RECURSION = False
-    def __init__(self, retries_count: int = 5, seconds_between_retries: int = 3,
-                 delivery_timeout_seconds: int = 10):
+
+    def __init__(
+        self,
+        retries_count: int = 5,
+        seconds_between_retries: int = 3,
+        delivery_timeout_seconds: int = 10
+    ):
         self.retries_count = retries_count
         self.seconds_between_retries = seconds_between_retries
         self.delivery_timeout_seconds = delivery_timeout_seconds
@@ -154,23 +165,32 @@ class EmailMimeSettings(Dictable):
         "message_sensitivity": EmailMessageSensitivity
     }
 
-    def __init__(self, plain_text_html_body_encoding: Union[EmailEncoding, str],
-                 text_attachment_encoding: Union[EmailEncoding, str],
-                 binary_attachment_encoding: Union[EmailEncoding, str],
-                 message_sensitivity: Union[EmailMessageSensitivity,
-                                            str], us_ascii_encoding: bool = False,
-                 non_us_ascii_quotes: bool = False, embed_html_attachments: bool = False,
-                 embed_all_attachments: bool = False, embed_adobe_flash_content: bool = False,
-                 html_table_position_only: bool = False, css_inline_style: bool = False):
+    def __init__(
+        self,
+        plain_text_html_body_encoding: Union[EmailEncoding, str],
+        text_attachment_encoding: Union[EmailEncoding, str],
+        binary_attachment_encoding: Union[EmailEncoding, str],
+        message_sensitivity: Union[EmailMessageSensitivity, str],
+        us_ascii_encoding: bool = False,
+        non_us_ascii_quotes: bool = False,
+        embed_html_attachments: bool = False,
+        embed_all_attachments: bool = False,
+        embed_adobe_flash_content: bool = False,
+        html_table_position_only: bool = False,
+        css_inline_style: bool = False
+    ):
         self.plain_text_html_body_encoding = EmailEncoding(
-            plain_text_html_body_encoding) if isinstance(plain_text_html_body_encoding,
-                                                         str) else plain_text_html_body_encoding
+            plain_text_html_body_encoding
+        ) if isinstance(plain_text_html_body_encoding, str) else plain_text_html_body_encoding
         self.text_attachment_encoding = EmailEncoding(text_attachment_encoding) if isinstance(
-            text_attachment_encoding, str) else text_attachment_encoding
+            text_attachment_encoding, str
+        ) else text_attachment_encoding
         self.binary_attachment_encoding = EmailEncoding(binary_attachment_encoding) if isinstance(
-            binary_attachment_encoding, str) else binary_attachment_encoding
+            binary_attachment_encoding, str
+        ) else binary_attachment_encoding
         self.message_sensitivity = EmailMessageSensitivity(message_sensitivity) if isinstance(
-            message_sensitivity, str) else message_sensitivity
+            message_sensitivity, str
+        ) else message_sensitivity
         self.us_ascii_encoding = us_ascii_encoding
         self.non_us_ascii_quotes = non_us_ascii_quotes
         self.embed_html_attachments = embed_html_attachments
@@ -192,9 +212,14 @@ class EmailSmartHostSettings(Dictable):
     """
     _DELETE_NONE_VALUES_RECURSION = False
 
-    def __init__(self, server: Optional[str] = None, port: Optional[int] = None,
-                 always_use_smart_host: bool = False, smart_host_username: Optional[str] = None,
-                 smart_host_password: bool = False):
+    def __init__(
+        self,
+        server: Optional[str] = None,
+        port: Optional[int] = None,
+        always_use_smart_host: bool = False,
+        smart_host_username: Optional[str] = None,
+        smart_host_password: bool = False
+    ):
         self.server = server
         self.port = port
         self.always_use_smart_host = always_use_smart_host
@@ -217,14 +242,19 @@ class EmailDeviceProperties(Dictable):
         "smart_host_settings": EmailSmartHostSettings.from_dict
     }
 
-    def __init__(self, format: Union[str, EmailFormat],
-                 mime_settings: Optional[Union[dict, EmailMimeSettings]] = None,
-                 smart_host_settings: Optional[Union[dict, EmailSmartHostSettings]] = None):
+    def __init__(
+        self,
+        format: Union[str, EmailFormat],
+        mime_settings: Optional[Union[dict, EmailMimeSettings]] = None,
+        smart_host_settings: Optional[Union[dict, EmailSmartHostSettings]] = None
+    ):
         self.format = EmailFormat(format) if isinstance(format, str) else format
         self.mime_settings = EmailMimeSettings.from_dict(mime_settings) if isinstance(
-            mime_settings, dict) else mime_settings
+            mime_settings, dict
+        ) else mime_settings
         self.smart_host_settings = EmailSmartHostSettings.from_dict(
-            smart_host_settings) if isinstance(smart_host_settings, dict) else smart_host_settings
+            smart_host_settings
+        ) if isinstance(smart_host_settings, dict) else smart_host_settings
 
 
 class FtpServerSettings(Dictable):
@@ -247,10 +277,18 @@ class FtpServerSettings(Dictable):
         "protocol": FtpProtocol,
     }
 
-    def __init__(self, protocol: Union[FtpProtocol,
-                                       str], port: int, path: str, host: Optional[str] = None,
-                 passive_mode: bool = True, max_connections: int = -1, ascii_mode: bool = True,
-                 user_name: Optional[str] = None, password: Optional[str] = None):
+    def __init__(
+        self,
+        protocol: Union[FtpProtocol, str],
+        port: int,
+        path: str,
+        host: Optional[str] = None,
+        passive_mode: bool = True,
+        max_connections: int = -1,
+        ascii_mode: bool = True,
+        user_name: Optional[str] = None,
+        password: Optional[str] = None
+    ):
         self.protocol = FtpProtocol(protocol) if isinstance(protocol, str) else protocol
         self.host = host
         self.port = port
@@ -275,12 +313,17 @@ class FtpDeviceProperties(Dictable):
         "file_system": FileSystem.from_dict,
     }
 
-    def __init__(self, server_settings: Union[FtpServerSettings, dict],
-                 file_system: Union[FileSystem, dict]):
+    def __init__(
+        self,
+        server_settings: Union[FtpServerSettings, dict],
+        file_system: Union[FileSystem, dict]
+    ):
         self.server_settings = FtpServerSettings.from_dict(server_settings) if isinstance(
-            server_settings, dict) else server_settings
-        self.file_system = FileSystem.from_dict(file_system) if isinstance(file_system,
-                                                                           dict) else file_system
+            server_settings, dict
+        ) else server_settings
+        self.file_system = FileSystem.from_dict(file_system) if isinstance(
+            file_system, dict
+        ) else file_system
 
 
 class IOSDeviceProperties(Dictable):
@@ -297,10 +340,15 @@ class IOSDeviceProperties(Dictable):
     """
     _DELETE_NONE_VALUES_RECURSION = False
 
-    def __init__(self, app_id: str = '', server: Optional[str] = None, port: Optional[int] = None,
-                 provider_certificate: Optional[str] = None,
-                 feedback_service_server: Optional[str] = None,
-                 feedback_service_port: Optional[int] = None):
+    def __init__(
+        self,
+        app_id: str = '',
+        server: Optional[str] = None,
+        port: Optional[int] = None,
+        provider_certificate: Optional[str] = None,
+        feedback_service_server: Optional[str] = None,
+        feedback_service_port: Optional[int] = None
+    ):
         self.app_id = app_id
         self.server = server
         self.port = port
@@ -327,11 +375,19 @@ class AndroidDeviceProperties(Dictable):
     """
     _DELETE_NONE_VALUES_RECURSION = False
 
-    def __init__(self, package_name: str, server: Optional[str] = None, port: Optional[int] = None,
-                 auth_key: Optional[str] = None, collapse_key: Optional[str] = None,
-                 delay_with_idle: bool = False, notification_active_hours: Optional[int] = None,
-                 use_proxy: bool = False, proxy_server: Optional[str] = None,
-                 proxy_port: Optional[int] = None):
+    def __init__(
+        self,
+        package_name: str,
+        server: Optional[str] = None,
+        port: Optional[int] = None,
+        auth_key: Optional[str] = None,
+        collapse_key: Optional[str] = None,
+        delay_with_idle: bool = False,
+        notification_active_hours: Optional[int] = None,
+        use_proxy: bool = False,
+        proxy_server: Optional[str] = None,
+        proxy_port: Optional[int] = None
+    ):
         self.package_name = package_name
         self.server = server
         self.port = port
@@ -355,8 +411,14 @@ class FileLocation(Dictable):
         backup_file_path: Backup File Location
     """
     _DELETE_NONE_VALUES_RECURSION = False
-    def __init__(self, file_path: str, append_user_path: bool = False,
-                 use_backup_location: bool = False, backup_file_path: Optional[str] = None):
+
+    def __init__(
+        self,
+        file_path: str,
+        append_user_path: bool = False,
+        use_backup_location: bool = False,
+        backup_file_path: Optional[str] = None
+    ):
         self.file_path = file_path
         self.append_user_path = append_user_path
         self.use_backup_location = use_backup_location
@@ -378,14 +440,19 @@ class FileProperties(Dictable):
         "file_encoding": FileEncoding,
     }
 
-    def __init__(self, read_only: bool = True, archive: bool = False, index: bool = False,
-                 file_encoding: Optional[Union[FileEncoding, str]] = None,
-                 unix_access_rights: Optional[str] = None):
+    def __init__(
+        self,
+        read_only: bool = True,
+        archive: bool = False,
+        index: bool = False,
+        file_encoding: Optional[Union[FileEncoding, str]] = None,
+        unix_access_rights: Optional[str] = None
+    ):
         self.read_only = read_only
         self.archive = archive
         self.index = index
-        self.file_encoding = FileEncoding(file_encoding) if isinstance(
-            file_encoding, str) else file_encoding
+        self.file_encoding = FileEncoding(file_encoding
+                                          ) if isinstance(file_encoding, str) else file_encoding
         self.unix_access_rights = unix_access_rights
 
 
@@ -400,8 +467,14 @@ class UnixWindowsSharity(Dictable):
         server_mount_root: IServer Mount root folder path for Sharity
     """
     _DELETE_NONE_VALUES_RECURSION = False
-    def __init__(self, sharity_enabled: bool = False, server_username: Optional[str] = None,
-                 server_password: Optional[str] = None, server_mount_root: Optional[str] = None):
+
+    def __init__(
+        self,
+        sharity_enabled: bool = False,
+        server_username: Optional[str] = None,
+        server_password: Optional[str] = None,
+        server_mount_root: Optional[str] = None
+    ):
         self.sharity_enabled = sharity_enabled
         self.server_username = server_username
         self.server_password = server_password
@@ -429,20 +502,26 @@ class FileDeviceProperties(Dictable):
         "unix_windows_sharity": UnixWindowsSharity.from_dict,
     }
 
-    def __init__(self, file_location: Union[FileLocation, dict],
-                 file_system: Union[FileSystem, dict],
-                 connection_parameters: Union[ConnectionParameters, dict],
-                 file_properties: Union[FileProperties, dict],
-                 unix_windows_sharity: Union[UnixWindowsSharity, dict]):
+    def __init__(
+        self,
+        file_location: Union[FileLocation, dict],
+        file_system: Union[FileSystem, dict],
+        connection_parameters: Union[ConnectionParameters, dict],
+        file_properties: Union[FileProperties, dict],
+        unix_windows_sharity: Union[UnixWindowsSharity, dict]
+    ):
         self.file_location = FileLocation.from_dict(file_location) if isinstance(
-            file_location, dict) else file_location
+            file_location, dict
+        ) else file_location
         self.file_system = FileSystem.from_dict(file_system) if isinstance(
-            file_system, dict) else file_system
+            file_system, dict
+        ) else file_system
         self.connection_parameters = ConnectionParameters.from_dict(
-            connection_parameters) if isinstance(
-            connection_parameters, dict) else connection_parameters
+            connection_parameters
+        ) if isinstance(connection_parameters, dict) else connection_parameters
         self.file_properties = FileProperties.from_dict(file_properties) if isinstance(
-            file_properties, dict) else file_properties
+            file_properties, dict
+        ) else file_properties
         self.unix_windows_sharity = UnixWindowsSharity.from_dict(
             unix_windows_sharity
         ) if isinstance(unix_windows_sharity, dict) else unix_windows_sharity
@@ -481,20 +560,25 @@ class PrinterPdfSettings(Dictable):
         "application_priority": PdfApplicationPriority,
     }
 
-    def __init__(self, post_script_level: int = 2, reverse_pages: bool = False,
-                 odd_even_pages: Optional[Union[PdfOddEvenPages, str]] = None,
-                 application_priority: Optional[Union[PdfApplicationPriority, str]] = None):
+    def __init__(
+        self,
+        post_script_level: int = 2,
+        reverse_pages: bool = False,
+        odd_even_pages: Optional[Union[PdfOddEvenPages, str]] = None,
+        application_priority: Optional[Union[PdfApplicationPriority, str]] = None
+    ):
         self.post_script_level = (
-            post_script_level if 0 <= post_script_level <= 9 else
-            exception_handler(
-                'Please provide appropriate value for post_script_level (from 0 to 9)',
-                ValueError)
+            post_script_level if 0 <= post_script_level <= 9 else exception_handler(
+                'Please provide appropriate value for post_script_level (from 0 to 9)', ValueError
+            )
         )
         self.odd_even_pages = PdfOddEvenPages(odd_even_pages) if isinstance(
-            odd_even_pages, str) else odd_even_pages
+            odd_even_pages, str
+        ) else odd_even_pages
         self.reverse_pages = reverse_pages
         self.application_priority = PdfApplicationPriority(application_priority) if isinstance(
-            application_priority, str) else application_priority
+            application_priority, str
+        ) else application_priority
 
 
 class PrinterProperties(Dictable):
@@ -514,17 +598,24 @@ class PrinterProperties(Dictable):
         "paper_size": PrinterPaperSize,
     }
 
-    def __init__(self, pdf_setting: Union[PrinterPdfSettings, dict], quality: Optional[str] = None,
-                 scale: int = 100, paper_source: Optional[Union[PrinterPaperSource, str]] = None,
-                 paper_size: Optional[Union[PrinterPaperSize, str]] = None):
+    def __init__(
+        self,
+        pdf_setting: Union[PrinterPdfSettings, dict],
+        quality: Optional[str] = None,
+        scale: int = 100,
+        paper_source: Optional[Union[PrinterPaperSource, str]] = None,
+        paper_size: Optional[Union[PrinterPaperSize, str]] = None
+    ):
         self.pdf_setting = PrinterPdfSettings.from_dict(pdf_setting) if isinstance(
-            pdf_setting, dict) else pdf_setting
+            pdf_setting, dict
+        ) else pdf_setting
         self.quality = quality
         self.scale = scale
         self.paper_source = PrinterPaperSource(paper_source) if isinstance(
-            paper_source, str) else paper_source
-        self.paper_size = PrinterPaperSize(paper_size) if isinstance(
-            paper_size, str) else paper_size
+            paper_source, str
+        ) else paper_source
+        self.paper_size = PrinterPaperSize(paper_size
+                                           ) if isinstance(paper_size, str) else paper_size
 
 
 class BackupPrinterProperties(Dictable):
@@ -543,13 +634,17 @@ class BackupPrinterProperties(Dictable):
         "backup_location_type": PrinterBackupLocationType,
     }
 
-    def __init__(self, print_on_backup: bool = False,
-                 backup_location_type: Optional[Union[PrinterBackupLocationType, str]] = None,
-                 backup_printer_location: Optional[str] = None,
-                 backup_file_location: Optional[str] = None):
+    def __init__(
+        self,
+        print_on_backup: bool = False,
+        backup_location_type: Optional[Union[PrinterBackupLocationType, str]] = None,
+        backup_printer_location: Optional[str] = None,
+        backup_file_location: Optional[str] = None
+    ):
         self.print_on_backup = print_on_backup
         self.backup_location_type = PrinterBackupLocationType(backup_location_type) if isinstance(
-            backup_file_location, str) else backup_location_type
+            backup_file_location, str
+        ) else backup_location_type
         self.backup_printer_location = backup_printer_location
         self.backup_file_location = backup_file_location
 
@@ -573,20 +668,24 @@ class PrinterDeviceProperties(Dictable):
         "backup_printer_properties": BackupPrinterProperties.from_dict,
     }
 
-    def __init__(self, printer_location: Union[PrinterLocation,
-                                               dict], printer_properties: Union[PrinterProperties,
-                                                                                dict],
-                 connection_parameters: Union[ConnectionParameters, dict],
-                 backup_printer_properties: Union[BackupPrinterProperties,
-                                                  dict], temp_file_location: Optional[str] = None):
+    def __init__(
+        self,
+        printer_location: Union[PrinterLocation, dict],
+        printer_properties: Union[PrinterProperties, dict],
+        connection_parameters: Union[ConnectionParameters, dict],
+        backup_printer_properties: Union[BackupPrinterProperties, dict],
+        temp_file_location: Optional[str] = None
+    ):
         self.printer_location = PrinterLocation.from_dict(printer_location) if isinstance(
-            printer_location, dict) else printer_location
+            printer_location, dict
+        ) else printer_location
         self.printer_properties = PrinterProperties.from_dict(printer_properties) if isinstance(
-            printer_properties, dict) else printer_properties
+            printer_properties, dict
+        ) else printer_properties
         self.connection_parameters = ConnectionParameters.from_dict(
-            connection_parameters) if isinstance(
-            connection_parameters, dict) else connection_parameters
+            connection_parameters
+        ) if isinstance(connection_parameters, dict) else connection_parameters
         self.backup_printer_properties = BackupPrinterProperties.from_dict(
-            backup_printer_properties) if isinstance(
-            backup_printer_properties, dict) else backup_printer_properties
+            backup_printer_properties
+        ) if isinstance(backup_printer_properties, dict) else backup_printer_properties
         self.temp_file_location = temp_file_location
