@@ -72,10 +72,15 @@ class ScheduleTime(Dictable):
             'execution_pattern': ScheduleEnums.ExecutionPattern,
         }
 
-        def __init__(self, execution_pattern: Union[ScheduleEnums.ExecutionPattern,
-                                                    str] = ScheduleEnums.ExecutionPattern.ONCE,
-                     execution_time: Optional[str] = None, start_time: Optional[str] = None,
-                     stop_time: Optional[str] = None, repeat_interval: Optional[int] = 1):
+        def __init__(
+            self,
+            execution_pattern: Union[ScheduleEnums.ExecutionPattern,
+                                     str] = ScheduleEnums.ExecutionPattern.ONCE,
+            execution_time: Optional[str] = None,
+            start_time: Optional[str] = None,
+            stop_time: Optional[str] = None,
+            repeat_interval: Optional[int] = 1
+        ):
             """Set attributes representing execution information of the schedule
 
             Args:
@@ -103,10 +108,13 @@ class ScheduleTime(Dictable):
             if (execution_pattern == ScheduleEnums.ExecutionPattern.REPEAT
                     and repeat_interval is None):
                 helper.exception_handler(
-                    msg=('Value error: execution_repeat_interval '
-                         'cannot be None, '
-                         'for execution_pattern == ExecutionPattern.Repeat'),
-                    exception_type=ValueError)
+                    msg=(
+                        'Value error: execution_repeat_interval '
+                        'cannot be None, '
+                        'for execution_pattern == ExecutionPattern.Repeat'
+                    ),
+                    exception_type=ValueError
+                )
             if execution_pattern == ScheduleEnums.ExecutionPattern.REPEAT:
                 self.start_time = start_time
                 self.stop_time = stop_time
@@ -123,9 +131,11 @@ class ScheduleTime(Dictable):
         _DELETE_NONE_VALUES_RECURSION = False
         _FROM_DICT_MAP = {'daily_pattern': ScheduleEnums.DailyPattern}
 
-        def __init__(self, daily_pattern: Union[ScheduleEnums.DailyPattern,
-                                                str] = ScheduleEnums.DailyPattern.DAY,
-                     repeat_interval: int = 1):
+        def __init__(
+            self,
+            daily_pattern: Union[ScheduleEnums.DailyPattern, str] = ScheduleEnums.DailyPattern.DAY,
+            repeat_interval: int = 1
+        ):
             """Set attributes representing daily recurrence information of the
             schedule
 
@@ -138,8 +148,8 @@ class ScheduleTime(Dictable):
                     if daily_pattern is DAY. Defaults to 1.
             """
             self.daily_pattern = daily_pattern if isinstance(
-                daily_pattern,
-                ScheduleEnums.DailyPattern) else ScheduleEnums.DailyPattern(daily_pattern)
+                daily_pattern, ScheduleEnums.DailyPattern
+            ) else ScheduleEnums.DailyPattern(daily_pattern)
             if daily_pattern == ScheduleEnums.DailyPattern.DAY:
                 self.repeat_interval = repeat_interval
 
@@ -149,9 +159,11 @@ class ScheduleTime(Dictable):
         _DELETE_NONE_VALUES_RECURSION = False
         _FROM_DICT_MAP = {'days_of_week': [ScheduleEnums.DaysOfWeek]}
 
-        def __init__(self, days_of_week: Optional[Union[List[ScheduleEnums.DaysOfWeek],
-                                                        List[str]]] = None,
-                     repeat_interval: int = 1):
+        def __init__(
+            self,
+            days_of_week: Optional[Union[List[ScheduleEnums.DaysOfWeek], List[str]]] = None,
+            repeat_interval: int = 1
+        ):
             """Set attributes representing weekly recurrence information of the
             schedule.
 
@@ -187,12 +199,16 @@ class ScheduleTime(Dictable):
             'weekday_offset': ScheduleEnums.WeekdayOffset
         }
 
-        def __init__(self, monthly_pattern: Union[ScheduleEnums.MonthlyPattern, str],
-                     repeat_interval: int, day: Optional[int] = None,
-                     week_offset: Optional[Union[ScheduleEnums.WeekOffset, str]] = None,
-                     day_of_week: Optional[Union[ScheduleEnums.DaysOfWeek, str]] = None,
-                     weekday_offset: Optional[Union[ScheduleEnums.WeekdayOffset, str]] = None,
-                     days_of_month: Optional[str] = None):
+        def __init__(
+            self,
+            monthly_pattern: Union[ScheduleEnums.MonthlyPattern, str],
+            repeat_interval: int,
+            day: Optional[int] = None,
+            week_offset: Optional[Union[ScheduleEnums.WeekOffset, str]] = None,
+            day_of_week: Optional[Union[ScheduleEnums.DaysOfWeek, str]] = None,
+            weekday_offset: Optional[Union[ScheduleEnums.WeekdayOffset, str]] = None,
+            days_of_month: Optional[str] = None
+        ):
             """Set attributes representing monthly recurrence information of the
             schedule.
 
@@ -226,23 +242,23 @@ class ScheduleTime(Dictable):
             """
 
             self.monthly_pattern = monthly_pattern if isinstance(
-                monthly_pattern,
-                ScheduleEnums.MonthlyPattern) else ScheduleEnums.MonthlyPattern(monthly_pattern)
+                monthly_pattern, ScheduleEnums.MonthlyPattern
+            ) else ScheduleEnums.MonthlyPattern(monthly_pattern)
             self.repeat_interval = repeat_interval
 
             if monthly_pattern == ScheduleEnums.MonthlyPattern.DAY:
                 self.day = day
             elif monthly_pattern == ScheduleEnums.MonthlyPattern.DAY_OF_WEEK:
                 self.week_offset = week_offset if isinstance(
-                    week_offset,
-                    ScheduleEnums.WeekOffset) else ScheduleEnums.WeekOffset(week_offset)
+                    week_offset, ScheduleEnums.WeekOffset
+                ) else ScheduleEnums.WeekOffset(week_offset)
                 self.day_of_week = day_of_week if isinstance(
-                    day_of_week,
-                    ScheduleEnums.DaysOfWeek) else ScheduleEnums.DaysOfWeek(day_of_week)
+                    day_of_week, ScheduleEnums.DaysOfWeek
+                ) else ScheduleEnums.DaysOfWeek(day_of_week)
             elif monthly_pattern == ScheduleEnums.MonthlyPattern.WEEKDAY:
                 self.weekday_offset = weekday_offset if isinstance(
-                    weekday_offset,
-                    ScheduleEnums.WeekdayOffset) else ScheduleEnums.WeekdayOffset(weekday_offset)
+                    weekday_offset, ScheduleEnums.WeekdayOffset
+                ) else ScheduleEnums.WeekdayOffset(weekday_offset)
             elif monthly_pattern == ScheduleEnums.MonthlyPattern.DAYS_OF_MONTH:
                 self.days_of_month = days_of_month
 
@@ -256,11 +272,15 @@ class ScheduleTime(Dictable):
             'day_of_week': ScheduleEnums.DaysOfWeek
         }
 
-        def __init__(self, yearly_pattern: Union[ScheduleEnums.YearlyPattern,
-                                                 str] = ScheduleEnums.YearlyPattern.DAY,
-                     month: int = 1, day: int = 1,
-                     week_offset: Optional[Union[ScheduleEnums.WeekOffset, str]] = None,
-                     day_of_week: Optional[Union[ScheduleEnums.DaysOfWeek, str]] = None):
+        def __init__(
+            self,
+            yearly_pattern: Union[ScheduleEnums.YearlyPattern,
+                                  str] = ScheduleEnums.YearlyPattern.DAY,
+            month: int = 1,
+            day: int = 1,
+            week_offset: Optional[Union[ScheduleEnums.WeekOffset, str]] = None,
+            day_of_week: Optional[Union[ScheduleEnums.DaysOfWeek, str]] = None
+        ):
             """Set attributes representing yearly recurrence information of the
             schedule
 
@@ -285,18 +305,18 @@ class ScheduleTime(Dictable):
                     SUNDAY. Defaults to None.
             """
             self.yearly_pattern = yearly_pattern if isinstance(
-                yearly_pattern,
-                ScheduleEnums.YearlyPattern) else ScheduleEnums.YearlyPattern(yearly_pattern)
+                yearly_pattern, ScheduleEnums.YearlyPattern
+            ) else ScheduleEnums.YearlyPattern(yearly_pattern)
             self.month = month
             if yearly_pattern == ScheduleEnums.YearlyPattern.DAY:
                 self.day = day
             if yearly_pattern == ScheduleEnums.YearlyPattern.DAYOFWEEK:
                 self.week_offset = week_offset if isinstance(
-                    week_offset,
-                    ScheduleEnums.WeekOffset) else ScheduleEnums.WeekOffset(week_offset)
+                    week_offset, ScheduleEnums.WeekOffset
+                ) else ScheduleEnums.WeekOffset(week_offset)
                 self.day_of_week = day_of_week if isinstance(
-                    day_of_week,
-                    ScheduleEnums.DaysOfWeek) else ScheduleEnums.DaysOfWeek(day_of_week)
+                    day_of_week, ScheduleEnums.DaysOfWeek
+                ) else ScheduleEnums.DaysOfWeek(day_of_week)
 
     _DELETE_NONE_VALUES_RECURSION = False
     _FROM_DICT_MAP = {
@@ -309,11 +329,15 @@ class ScheduleTime(Dictable):
         'yearly': Yearly.from_dict
     }
 
-    def __init__(self, recurrence_pattern: Optional[Union[ScheduleEnums.RecurrencePattern,
-                                                          str]] = None,
-                 execution: Optional[Execution] = None, daily: Optional[Daily] = None,
-                 weekly: Optional[Weekly] = None, monthly: Optional[Monthly] = None,
-                 yearly: Optional[Yearly] = None):
+    def __init__(
+        self,
+        recurrence_pattern: Optional[Union[ScheduleEnums.RecurrencePattern, str]] = None,
+        execution: Optional[Execution] = None,
+        daily: Optional[Daily] = None,
+        weekly: Optional[Weekly] = None,
+        monthly: Optional[Monthly] = None,
+        yearly: Optional[Yearly] = None
+    ):
         """Set attributes representing details of the time-based schedule.
 
         Args:
@@ -351,27 +375,31 @@ class ScheduleTime(Dictable):
             self.yearly = yearly
 
     @classmethod
-    def from_details(cls, recurrence_pattern: Union[ScheduleEnums.RecurrencePattern, str],
-                     execution_pattern: Union[ScheduleEnums.ExecutionPattern,
-                                              str], execution_time: Optional[str] = None,
-                     start_time: Optional[str] = None, stop_time: Optional[str] = None,
-                     execution_repeat_interval: Optional[int] = None,
-                     daily_pattern: Optional[Union[ScheduleEnums.DailyPattern,
-                                                   str]] = ScheduleEnums.DailyPattern.NONE,
-                     repeat_interval: Optional[int] = None,
-                     days_of_week: Optional[Union[List[ScheduleEnums.DaysOfWeek],
-                                                  List[str]]] = None, day: Optional[int] = None,
-                     month: Optional[int] = None,
-                     week_offset: Optional[Union[ScheduleEnums.WeekOffset,
-                                                 str]] = ScheduleEnums.WeekOffset.NONE,
-                     day_of_week: Optional[Union[ScheduleEnums.DaysOfWeek,
-                                                 str]] = ScheduleEnums.DaysOfWeek.NONE,
-                     weekday_offset: Optional[str] = None,
-                     days_of_month: Optional[List[str]] = None,
-                     monthly_pattern: Optional[Union[ScheduleEnums.MonthlyPattern,
-                                                     str]] = ScheduleEnums.MonthlyPattern.NONE,
-                     yearly_pattern: Optional[Union[ScheduleEnums.YearlyPattern,
-                                                    str]] = ScheduleEnums.YearlyPattern.NONE):
+    def from_details(
+        cls,
+        recurrence_pattern: Union[ScheduleEnums.RecurrencePattern, str],
+        execution_pattern: Union[ScheduleEnums.ExecutionPattern, str],
+        execution_time: Optional[str] = None,
+        start_time: Optional[str] = None,
+        stop_time: Optional[str] = None,
+        execution_repeat_interval: Optional[int] = None,
+        daily_pattern: Optional[Union[ScheduleEnums.DailyPattern,
+                                      str]] = ScheduleEnums.DailyPattern.NONE,
+        repeat_interval: Optional[int] = None,
+        days_of_week: Optional[Union[List[ScheduleEnums.DaysOfWeek], List[str]]] = None,
+        day: Optional[int] = None,
+        month: Optional[int] = None,
+        week_offset: Optional[Union[ScheduleEnums.WeekOffset,
+                                    str]] = ScheduleEnums.WeekOffset.NONE,
+        day_of_week: Optional[Union[ScheduleEnums.DaysOfWeek,
+                                    str]] = ScheduleEnums.DaysOfWeek.NONE,
+        weekday_offset: Optional[str] = None,
+        days_of_month: Optional[List[str]] = None,
+        monthly_pattern: Optional[Union[ScheduleEnums.MonthlyPattern,
+                                        str]] = ScheduleEnums.MonthlyPattern.NONE,
+        yearly_pattern: Optional[Union[ScheduleEnums.YearlyPattern,
+                                       str]] = ScheduleEnums.YearlyPattern.NONE
+    ):
         """
         Uses provided properties to create object representation of details of a
         time-based schedule.
@@ -448,76 +476,93 @@ class ScheduleTime(Dictable):
         """
 
         if execution_pattern == ScheduleEnums.ExecutionPattern.ONCE:
-            execution = cls.Execution.from_dict({
-                'execution_pattern': execution_pattern,
-                'execution_time': execution_time
-            })
+            execution = cls.Execution.from_dict(
+                {
+                    'execution_pattern': execution_pattern, 'execution_time': execution_time
+                }
+            )
         elif execution_pattern == ScheduleEnums.ExecutionPattern.REPEAT:
-            execution = cls.Execution.from_dict({
-                'execution_pattern': execution_pattern,
-                'start_time': start_time,
-                'stop_time': stop_time,
-                'repeat_interval': execution_repeat_interval
-            })
+            execution = cls.Execution.from_dict(
+                {
+                    'execution_pattern': execution_pattern,
+                    'start_time': start_time,
+                    'stop_time': stop_time,
+                    'repeat_interval': execution_repeat_interval
+                }
+            )
         else:
-            helper.exception_handler(msg='Error: Wrong value of execution_pattern',
-                                     exception_type=ValueError)
+            helper.exception_handler(
+                msg='Error: Wrong value of execution_pattern', exception_type=ValueError
+            )
 
         if recurrence_pattern == ScheduleEnums.RecurrencePattern.DAILY:
-            daily = cls.Daily.from_dict({
-                'daily_pattern': daily_pattern,
-                'repeat_interval': repeat_interval
-            })
+            daily = cls.Daily.from_dict(
+                {
+                    'daily_pattern': daily_pattern, 'repeat_interval': repeat_interval
+                }
+            )
             return cls(recurrence_pattern=recurrence_pattern, execution=execution, daily=daily)
         elif recurrence_pattern == ScheduleEnums.RecurrencePattern.WEEKLY:
             if days_of_week and type(days_of_week) is not list:
-                helper.exception_handler(msg='Error: days_of_week must be provided as a list',
-                                         exception_type=ValueError)
-            weekly = cls.Weekly.from_dict({
-                'repeat_interval': repeat_interval,
-                'days_of_week': days_of_week
-            })
+                helper.exception_handler(
+                    msg='Error: days_of_week must be provided as a list',
+                    exception_type=ValueError
+                )
+            weekly = cls.Weekly.from_dict(
+                {
+                    'repeat_interval': repeat_interval, 'days_of_week': days_of_week
+                }
+            )
             return cls(recurrence_pattern=recurrence_pattern, execution=execution, weekly=weekly)
         elif recurrence_pattern == ScheduleEnums.RecurrencePattern.MONTHLY:
-            monthly = cls.Monthly.from_dict({
-                "monthly_pattern": monthly_pattern,
-                "repeatInterval": repeat_interval,
-                "day": day,
-                "week_offset": week_offset,
-                "day_of_week": day_of_week,
-                "WeekdayOffset": weekday_offset,
-                "days_of_month": days_of_month
-            })
+            monthly = cls.Monthly.from_dict(
+                {
+                    "monthly_pattern": monthly_pattern,
+                    "repeatInterval": repeat_interval,
+                    "day": day,
+                    "week_offset": week_offset,
+                    "day_of_week": day_of_week,
+                    "WeekdayOffset": weekday_offset,
+                    "days_of_month": days_of_month
+                }
+            )
             return cls(recurrence_pattern=recurrence_pattern, execution=execution, monthly=monthly)
         elif recurrence_pattern == ScheduleEnums.RecurrencePattern.YEARLY:
-            yearly = cls.Yearly.from_dict({
-                'yearly_pattern': yearly_pattern,
-                'month': month,
-                'day': day,
-                'week_offset': week_offset,
-                'day_of_week': day_of_week
-            })
+            yearly = cls.Yearly.from_dict(
+                {
+                    'yearly_pattern': yearly_pattern,
+                    'month': month,
+                    'day': day,
+                    'week_offset': week_offset,
+                    'day_of_week': day_of_week
+                }
+            )
             return cls(recurrence_pattern=recurrence_pattern, execution=execution, yearly=yearly)
         else:
-            helper.exception_handler(msg='Error: Wrong value of recurrence_pattern',
-                                     exception_type=ValueError)
+            helper.exception_handler(
+                msg='Error: Wrong value of recurrence_pattern', exception_type=ValueError
+            )
 
     def update_properties(
-            self, recurrence_pattern: Optional[Union[ScheduleEnums.RecurrencePattern, str]] = None,
-            execution_pattern: Optional[Union[ScheduleEnums.ExecutionPattern, str]] = None,
-            execution_time: Optional[str] = None, start_time: Optional[str] = None,
-            stop_time: Optional[str] = None, execution_repeat_interval: Optional[int] = None,
-            daily_pattern: Optional[Union[ScheduleEnums.DailyPattern,
-                                          str]] = None, repeat_interval: Optional[int] = None,
-            days_of_week: Optional[Union[List[ScheduleEnums.DaysOfWeek],
-                                         List[str]]] = None, day: Optional[int] = None,
-            month: Optional[int] = None, week_offset: Optional[Union[ScheduleEnums.WeekOffset,
-                                                                     str]] = None,
-            day_of_week: Optional[Union[ScheduleEnums.DaysOfWeek, str]] = None,
-            weekday_offset: Optional[Union[ScheduleEnums.WeekdayOffset,
-                                           str]] = None, days_of_month: Optional[List[str]] = None,
-            monthly_pattern: Optional[Union[ScheduleEnums.MonthlyPattern, str]] = None,
-            yearly_pattern: Optional[Union[ScheduleEnums.YearlyPattern, str]] = None):
+        self,
+        recurrence_pattern: Optional[Union[ScheduleEnums.RecurrencePattern, str]] = None,
+        execution_pattern: Optional[Union[ScheduleEnums.ExecutionPattern, str]] = None,
+        execution_time: Optional[str] = None,
+        start_time: Optional[str] = None,
+        stop_time: Optional[str] = None,
+        execution_repeat_interval: Optional[int] = None,
+        daily_pattern: Optional[Union[ScheduleEnums.DailyPattern, str]] = None,
+        repeat_interval: Optional[int] = None,
+        days_of_week: Optional[Union[List[ScheduleEnums.DaysOfWeek], List[str]]] = None,
+        day: Optional[int] = None,
+        month: Optional[int] = None,
+        week_offset: Optional[Union[ScheduleEnums.WeekOffset, str]] = None,
+        day_of_week: Optional[Union[ScheduleEnums.DaysOfWeek, str]] = None,
+        weekday_offset: Optional[Union[ScheduleEnums.WeekdayOffset, str]] = None,
+        days_of_month: Optional[List[str]] = None,
+        monthly_pattern: Optional[Union[ScheduleEnums.MonthlyPattern, str]] = None,
+        yearly_pattern: Optional[Union[ScheduleEnums.YearlyPattern, str]] = None
+    ):
         """
         Updates ScheduleTime object according to provided parameters. If a
         provided parameter is not None then update it, else use its current
@@ -593,80 +638,101 @@ class ScheduleTime(Dictable):
         self.recurrence_pattern = recurrence_pattern or self.recurrence_pattern
 
         if self.execution.execution_pattern == ScheduleEnums.ExecutionPattern.ONCE:
-            self.execution = self.Execution.from_dict({
-                'execution_pattern': execution_pattern or self.execution.execution_pattern,
-                'execution_time': execution_time or self.execution.execution_time
-            })
+            self.execution = self.Execution.from_dict(
+                {
+                    'execution_pattern': execution_pattern or self.execution.execution_pattern,
+                    'execution_time': execution_time or self.execution.execution_time
+                }
+            )
         elif self.execution.execution_pattern == ScheduleEnums.ExecutionPattern.REPEAT:
-            self.execution = self.Execution.from_dict({
-                'execution_pattern': execution_pattern or self.execution.execution_pattern,
-                'start_time': start_time or self.execution.start_time,
-                'stop_time': stop_time or self.execution.stop_time,
-                'repeat_interval': execution_repeat_interval or self.execution.repeat_interval
-            })
+            self.execution = self.Execution.from_dict(
+                {
+                    'execution_pattern': execution_pattern or self.execution.execution_pattern,
+                    'start_time': start_time or self.execution.start_time,
+                    'stop_time': stop_time or self.execution.stop_time,
+                    'repeat_interval': execution_repeat_interval or self.execution.repeat_interval
+                }
+            )
 
         if self.recurrence_pattern == ScheduleEnums.RecurrencePattern.DAILY:
             if hasattr(self, 'daily') and self.daily:
-                self.daily = self.Daily.from_dict({
-                    'daily_pattern': daily_pattern or self.daily.daily_pattern,
-                    'repeat_interval': (repeat_interval
-                                        or getattr(self.daily, 'repeat_interval', None))
-                })
+                self.daily = self.Daily.from_dict(
+                    {
+                        'daily_pattern': daily_pattern or self.daily.daily_pattern,
+                        'repeat_interval': (
+                            repeat_interval or getattr(self.daily, 'repeat_interval', None)
+                        )
+                    }
+                )
             else:
-                self.daily = self.Daily.from_dict({
-                    'daily_pattern': daily_pattern,
-                    'repeat_interval': repeat_interval
-                })
+                self.daily = self.Daily.from_dict(
+                    {
+                        'daily_pattern': daily_pattern, 'repeat_interval': repeat_interval
+                    }
+                )
 
         if self.recurrence_pattern == ScheduleEnums.RecurrencePattern.WEEKLY:
             if hasattr(self, 'weekly') and self.weekly:
-                self.weekly = self.Weekly.from_dict({
-                    'repeat_interval': repeat_interval or self.weekly.repeat_interval,
-                    'days_of_week': days_of_week or self.weekly.days_of_week
-                })
+                self.weekly = self.Weekly.from_dict(
+                    {
+                        'repeat_interval': repeat_interval or self.weekly.repeat_interval,
+                        'days_of_week': days_of_week or self.weekly.days_of_week
+                    }
+                )
             else:
-                self.weekly = self.Weekly.from_dict({
-                    'repeat_interval': repeat_interval,
-                    'days_of_week': days_of_week
-                })
+                self.weekly = self.Weekly.from_dict(
+                    {
+                        'repeat_interval': repeat_interval, 'days_of_week': days_of_week
+                    }
+                )
 
         if self.recurrence_pattern == ScheduleEnums.RecurrencePattern.MONTHLY:
             if hasattr(self, 'monthly') and self.monthly:
-                self.monthly = self.Monthly.from_dict({
-                    "monthly_pattern": monthly_pattern or self.monthly.monthly_pattern,
-                    "repeat_interval": repeat_interval or self.monthly.repeat_interval,
-                    "day": day or getattr(self.monthly, 'day', None),
-                    "week_offset": week_offset or getattr(self.monthly, 'week_offset', None),
-                    "day_of_week": day_of_week or getattr(self.monthly, 'day_of_week', None),
-                    "weekday_offset": (weekday_offset
-                                       or getattr(self.monthly, 'weekday_offset', None)),
-                    "days_of_month": days_of_month or getattr(self.monthly, 'days_of_month', None)
-                })
+                self.monthly = self.Monthly.from_dict(
+                    {
+                        "monthly_pattern": monthly_pattern or self.monthly.monthly_pattern,
+                        "repeat_interval": repeat_interval or self.monthly.repeat_interval,
+                        "day": day or getattr(self.monthly, 'day', None),
+                        "week_offset": week_offset or getattr(self.monthly, 'week_offset', None),
+                        "day_of_week": day_of_week or getattr(self.monthly, 'day_of_week', None),
+                        "weekday_offset": (
+                            weekday_offset or getattr(self.monthly, 'weekday_offset', None)
+                        ),
+                        "days_of_month": days_of_month
+                        or getattr(self.monthly, 'days_of_month', None)
+                    }
+                )
             else:
-                self.monthly = self.Monthly.from_dict({
-                    "monthly_pattern": monthly_pattern,
-                    "repeat_interval": repeat_interval,
-                    "day": day,
-                    "week_offset": week_offset,
-                    "day_of_week": day_of_week,
-                    "weekday_offset": weekday_offset,
-                    "days_of_month": days_of_month
-                })
+                self.monthly = self.Monthly.from_dict(
+                    {
+                        "monthly_pattern": monthly_pattern,
+                        "repeat_interval": repeat_interval,
+                        "day": day,
+                        "week_offset": week_offset,
+                        "day_of_week": day_of_week,
+                        "weekday_offset": weekday_offset,
+                        "days_of_month": days_of_month
+                    }
+                )
 
         if self.recurrence_pattern == ScheduleEnums.RecurrencePattern.YEARLY:
             if hasattr(self, 'yearly') and self.yearly:
-                self.yearly = self.Yearly.from_dict({
-                    'yearly_pattern': yearly_pattern or self.yearly.yearly_pattern,
-                    'month': month or getattr(self.yearly, 'month', None),
-                    'day': day or getattr(self.yearly, 'day', None),
-                    'week_offset': week_offset or getattr(self.yearly, 'week_offset', None),
-                    'day_of_week': day_of_week or getattr(self.yearly, 'day_of_week', None),
-                })
+                self.yearly = self.Yearly.from_dict(
+                    {
+                        'yearly_pattern': yearly_pattern or self.yearly.yearly_pattern,
+                        'month': month or getattr(self.yearly, 'month', None),
+                        'day': day or getattr(self.yearly, 'day', None),
+                        'week_offset': week_offset or getattr(self.yearly, 'week_offset', None),
+                        'day_of_week': day_of_week or getattr(self.yearly, 'day_of_week', None),
+                    }
+                )
             else:
-                self.yearly = self.Yearly.from_dict({
-                    'yearly_pattern': yearly_pattern,
-                    'month': month,
-                    'day': day,
-                    'week_offset': week_offset,
-                    'day_of_week': day_of_week
-                })
+                self.yearly = self.Yearly.from_dict(
+                    {
+                        'yearly_pattern': yearly_pattern,
+                        'month': month,
+                        'day': day,
+                        'week_offset': week_offset,
+                        'day_of_week': day_of_week
+                    }
+                )
