@@ -9,8 +9,16 @@ from .folder import (
 # isort: on
 from .search_enums import CertifiedStatus, SearchDomain, SearchPattern, SearchResultsFormat
 from .search_operations import (
-    CertifiedStatus, full_search, get_search_results, get_search_suggestions, quick_search,
-    quick_search_from_object, SearchDomain, SearchObject, SearchPattern, SearchResultsFormat,
+    CertifiedStatus,
+    full_search,
+    get_search_results,
+    get_search_suggestions,
+    quick_search,
+    quick_search_from_object,
+    SearchDomain,
+    SearchObject,
+    SearchPattern,
+    SearchResultsFormat,
     start_full_search
 )
 from .shortcut import get_shortcuts, Shortcut, ShortcutInfoFlags
