@@ -18,7 +18,7 @@ from mstrio.utils.version_helper import method_version_handler
 
 if TYPE_CHECKING:
     from mstrio.access_and_security.privilege import Privilege
-    from mstrio.access_and_security.security_filter import SecurityFilter
+    from mstrio.modeling.security_filter import SecurityFilter
     from mstrio.server.project import Project
     from mstrio.users_and_groups.user_group import UserGroup
 
@@ -625,7 +625,7 @@ class User(Entity, DeleteMixin, TrusteeACLMixin):
             in the particular project, then this project is not placed in
             the dictionary.
         """
-        from mstrio.access_and_security.security_filter import SecurityFilter
+        from mstrio.modeling.security_filter import SecurityFilter
         objects_ = users.get_security_filters(self.connection, self.id, projects).json()
         projects_ = objects_.get("projects")
 
@@ -654,7 +654,7 @@ class User(Entity, DeleteMixin, TrusteeACLMixin):
             True when applying was successful. False otherwise.
         """
         if isinstance(security_filter, str):
-            from mstrio.access_and_security.security_filter import SecurityFilter
+            from mstrio.modeling.security_filter import SecurityFilter
             security_filter = SecurityFilter.from_dict({"id": security_filter}, self.connection)
         return security_filter.apply(self.id)
 
@@ -669,7 +669,7 @@ class User(Entity, DeleteMixin, TrusteeACLMixin):
             True when revoking was successful. False otherwise.
         """
         if isinstance(security_filter, str):
-            from mstrio.access_and_security.security_filter import SecurityFilter
+            from mstrio.modeling.security_filter import SecurityFilter
             security_filter = SecurityFilter.from_dict({"id": security_filter}, self.connection)
         return security_filter.revoke(self.id)
 
