@@ -1,3 +1,4 @@
+import logging
 from typing import Any, Dict, List, Optional, TYPE_CHECKING, Union
 
 from packaging import version
@@ -7,12 +8,16 @@ from mstrio.api import monitors
 from mstrio.connection import Connection
 from mstrio.server import Cluster
 from mstrio.utils import helper
+from mstrio.utils.version_helper import class_version_handler
 
 if TYPE_CHECKING:
     from mstrio.users_and_groups.user import User
 
+logger = logging.getLogger(__name__)
 
-class UserConnections():
+
+@class_version_handler('11.2.0000')
+class UserConnections:
     """Browse and manage active user connections on the environment. Use the
     `fetch()` method to fetch the latest active user connections. Filter the
     `user_connections` by using `filter_connections()` method.
@@ -52,13 +57,15 @@ class UserConnections():
         if not self.user_connections:
             helper.exception_handler(
                 "Populate the `UserConnections` object with `UserConnections.fetch` first.",
-                Warning)
+                Warning
+            )
         else:
             filtered_connections = helper.filter_list_of_dicts(self.user_connections, **filters)
         return filtered_connections
 
-    def list_connections(self, nodes: Union[str, List[str]] = None, limit: Optional[int] = None,
-                         **filters) -> List[Dict[str, Any]]:
+    def list_connections(
+        self, nodes: Union[str, List[str]] = None, limit: Optional[int] = None, **filters
+    ) -> List[Dict[str, Any]]:
         """Get all active user connections. Optionally filter the connections
         by specifying the `filters` keyword arguments.
 
@@ -72,7 +79,7 @@ class UserConnections():
                 'date_connection_created', 'duration', 'session_id', 'client',
                 'config_level']
         """
-        # TODO: This fully initialises a Cluster object every timethe function
+        # TODO: This fully initialises a Cluster object every time the function
         # is run. It would be better to somehow cache it for a given connection.
         all_nodes = Cluster(self.connection).list_nodes(to_dictionary=True)
         all_connections = []
@@ -81,21 +88,31 @@ class UserConnections():
         else:
             nodes = nodes if isinstance(nodes, list) else [nodes]
 
-        msg = "Error fetching chunk of active user connections."
+        msg = 'Error fetching chunk of active user connections.'
         for node in nodes:
             all_connections.extend(
-                helper.fetch_objects_async(self.connection, monitors.get_user_connections,
-                                           monitors.get_user_connections_async,
-                                           dict_unpack_value="userConnections", limit=limit,
-                                           chunk_size=1000, error_msg=msg, node_name=node,
-                                           filters=filters))
+                helper.fetch_objects_async(
+                    self.connection,
+                    monitors.get_user_connections,
+                    monitors.get_user_connections_async,
+                    dict_unpack_value="userConnections",
+                    limit=limit,
+                    chunk_size=1000,
+                    error_msg=msg,
+                    node_name=node,
+                    filters=filters
+                )
+            )
         return all_connections
 
-    def disconnect_users(self, connection_ids: Union[str, List[str]] = None,
-                         users: Optional[Union[List["User"],
-                                               List[str]]] = None, nodes: Union[str,
-                                                                                List[str]] = None,
-                         force: bool = False, **filters) -> Union[List[dict], None]:
+    def disconnect_users(
+        self,
+        connection_ids: Union[str, List[str]] = None,
+        users: Optional[Union[List["User"], List[str]]] = None,
+        nodes: Union[str, List[str]] = None,
+        force: bool = False,
+        **filters
+    ) -> Union[List[dict], None]:
         """Disconnect user connections by passing in users (objects) or
         connection_ids. Optionally disconnect users by specifying the `filters`
         keyword arguments.
@@ -126,8 +143,10 @@ class UserConnections():
         from mstrio.users_and_groups.user import User  # import here to avoid circular imports
 
         if self.connection and not connection_ids and not users and not filters and not force:
-            msg = ("You need to pass connection_ids or users or specify filters. To disconnect "
-                   "all connections use `disconnect_all_users()` method.")
+            msg = (
+                "You need to pass connection_ids or users or specify filters. To disconnect "
+                "all connections use `disconnect_all_users()` method."
+            )
             helper.exception_handler(msg)
 
         if connection_ids:
@@ -147,17 +166,19 @@ class UserConnections():
                     else:
                         helper.exception_handler(
                             "'user' param must be a list of User objects or usernames.",
-                            exception_type=TypeError)
+                            exception_type=TypeError
+                        )
 
                 all_connections = list(
-                    filter(lambda conn: conn['username'] in usernames, all_connections))
+                    filter(lambda conn: conn['username'] in usernames, all_connections)
+                )
 
             if all_connections:
                 # extract connection ids and disconnect
                 connection_ids = [conn['id'] for conn in all_connections]
                 return self.__disconnect_by_connection_id(connection_ids)
             elif config.verbose:
-                print("No active user connections")
+                logger.info('No active user connections.')
 
     def disconnect_all_users(self, force: bool = False) -> Union[List[dict], None]:
         """Disconnect all user connections.
@@ -173,7 +194,8 @@ class UserConnections():
         """
         if not force:
             user_input = input(
-                "Are you sure you want to disconnect all users from the I-Server? [Y/N]: ")
+                "Are you sure you want to disconnect all users from the I-Server? [Y/N]: "
+            )
             if user_input != "Y":
                 return None
             else:
@@ -182,7 +204,8 @@ class UserConnections():
         return self.disconnect_users(force=force)
 
     def __disconnect_by_connection_id(
-            self, connection_ids: Union[str, List[str]]) -> Union[List[dict], None]:
+        self, connection_ids: Union[str, List[str]]
+    ) -> Union[List[dict], None]:
         """It disconnects connections which ids are provided in
         'connection_ids'. It prints information about executed operations.
         Returns list of statuses of for the given connection ids with the
@@ -198,9 +221,10 @@ class UserConnections():
             if res.status_code in [200, 207] or (res.status_code == 403
                                                  and not res.json().get('code', None)):
                 return self._prepare_disconnect_by_id_message(
-                    statuses=res.json()['deleteUserConnectionsStatus'])
+                    statuses=res.json()['deleteUserConnectionsStatus']
+                )
             else:
-                err_msg = f"Error disconnecting user sessions: {connection_ids}."
+                err_msg = f'Error disconnecting user sessions: {connection_ids}.'
                 return helper.response_handler(response=res, msg=err_msg, throw_error=False)
         else:
             # TODO: This can probably be made more elegant and potentially
@@ -208,8 +232,9 @@ class UserConnections():
             # and maybe use comprehension instead of appending in loop.
             statuses: List[Dict[str, Union[str, int]]] = []
             for connection_id in connection_ids:
-                response = monitors.delete_user_connection(self.connection, connection_id,
-                                                           bulk=True)
+                response = monitors.delete_user_connection(
+                    self.connection, connection_id, bulk=True
+                )
                 statuses.append({'id': connection_id, 'status': response.status_code})
             return self._prepare_disconnect_by_id_message(statuses=statuses)
 
@@ -229,10 +254,14 @@ class UserConnections():
 
         if config.verbose:
             if succeeded:
-                print("User connections with ids below were successfully disconnected:\n\t"
-                      + ',\n\t'.join(succeeded))
+                logger.info(
+                    'User connections with ids below were successfully disconnected:\n\t'
+                    + ',\n\t'.join(succeeded)
+                )
             if failed:
-                print("User connections with ids below were not disconnected:\n\t"
-                      + ',\n\t'.join(failed))
+                logger.warning(
+                    'User connections with ids below were not disconnected:\n\t'
+                    + ',\n\t'.join(failed)
+                )
 
         return statuses
