@@ -1,20 +1,24 @@
 from enum import auto, Enum
 import functools
 from itertools import filterfalse
+import logging
 import sys
 from textwrap import dedent
 from typing import Optional, Union
-from warnings import warn
 
 from packaging.version import Version
 
 from .. import __version__, config
 
+logger = logging.getLogger(__name__)
+logging.basicConfig(level=logging.INFO, format='%(message)s', stream=sys.stderr)  # NOSONAR
+
 current_version = Version(__version__)
 
 
 class WipLevels(Enum):
     SILENT = auto()
+    PREVIEW = auto()
     INFO = auto()
     WARNING = auto()
     ERROR = auto()
@@ -26,24 +30,32 @@ def _wiplevel_error(level):
 
 # TODO: Discuss exact strings with UX.
 message_templates = {
-    WipLevels.INFO:
-        "This {}functionality is a work-in-progress. It may change in future updates.",
-    WipLevels.WARNING:
-        ("This {}functionality is a work-in-progress. Use it only if you understand"
-         " the underlying code. It may change in future updates."),
-    WipLevels.ERROR:
-        ("This {}functionality is a work-in-progress. It has been deemed unsafe to use"
-         " and is currently blocked."),
+    WipLevels.PREVIEW: (
+        "In a current version, {}is available as "
+        "a Functionality Preview. It is subject to change until it is released "
+        "as Generally Available."
+    ),
+    WipLevels.INFO: "This {}functionality is a work-in-progress. It may change in future updates.",
+    WipLevels.WARNING: (
+        "This {}functionality is a work-in-progress. Use it only if you understand"
+        " the underlying code. It may change in future updates."
+    ),
+    WipLevels.ERROR: (
+        "This {}functionality is a work-in-progress. It has been deemed unsafe to use"
+        " and is currently blocked."
+    ),
 }
 release_info_template = " It is currently scheduled for {} release."
-docstring_prefix_template = dedent("""\
+docstring_prefix_template = dedent(
+    """\
     ------------------ WORK IN PROGRESS ------------------
 
     {}
 
     ------------------------------------------------------
 
-""")
+"""
+)
 
 
 def _get_message_template(level: WipLevels = WipLevels.WARNING):
@@ -53,9 +65,11 @@ def _get_message_template(level: WipLevels = WipLevels.WARNING):
         return message_templates[WipLevels.INFO]
 
 
-def _construct_message(name: Optional[str] = None,
-                       target_release: Optional[Union[Version, str]] = None,
-                       level: WipLevels = WipLevels.WARNING):
+def _construct_message(
+    name: Optional[str] = None,
+    target_release: Optional[Union[Version, str]] = None,
+    level: WipLevels = WipLevels.WARNING
+):
     template = _get_message_template(level)
     if name is None:
         message = template.format("")
@@ -66,27 +80,35 @@ def _construct_message(name: Optional[str] = None,
     return message
 
 
-def _emit(name: Optional[str] = None, target_release: Optional[Union[Version, str]] = None,
-          level: WipLevels = WipLevels.WARNING, message: Optional[str] = None):
+def _emit(
+    name: Optional[str] = None,
+    target_release: Optional[Union[Version, str]] = None,
+    level: WipLevels = WipLevels.WARNING,
+    message: Optional[str] = None
+):
     if level == WipLevels.SILENT or not config.wip_warnings_enabled:
         return None
 
     if message is None:
         message = _construct_message(name, target_release, level)
 
-    if level == WipLevels.INFO:
-        print(message, file=sys.stderr)
+    if level == WipLevels.INFO or level == WipLevels.PREVIEW:
+        logger.info(message)
     elif level == WipLevels.WARNING:
-        warn(message)
+        logger.warning(message)
     elif level == WipLevels.ERROR:
         raise NotImplementedError(message)
     else:
         _wiplevel_error(level)
 
 
-def wip(target_release: Optional[Union[Version, str]] = None, level: WipLevels = WipLevels.WARNING,
-        message: Optional[str] = None, prefix_doc: Union[bool, str] = True,
-        mark_attr: bool = True):
+def wip(
+    target_release: Optional[Union[Version, str]] = None,
+    level: WipLevels = WipLevels.WARNING,
+    message: Optional[str] = None,
+    prefix_doc: Union[bool, str] = True,
+    mark_attr: bool = True
+):
     """Work-In-Progress wrapper
 
     Note:
@@ -100,6 +122,7 @@ def wip(target_release: Optional[Union[Version, str]] = None, level: WipLevels =
         level: The severity level of the warning emitted when the functionality
             is loaded or used.
             SILENT: no warning will be emitted
+            PREVIEW: a warning will be dispatched
             INFO: a disclaimer will be printed to stderr
             WARNING: a warning will be dispatched
             ERROR: an error will be raised
@@ -113,8 +136,10 @@ def wip(target_release: Optional[Union[Version, str]] = None, level: WipLevels =
         if not isinstance(target_release, Version):
             target_release = Version(target_release)
         if target_release <= current_version:
-            raise ValueError("WIP wrapper called with target_release equal to"
-                             " or lower than current release.")
+            raise ValueError(
+                "WIP wrapper called with target_release equal to"
+                " or lower than current release."
+            )
     if level not in WipLevels:
         _wiplevel_error(level)
 
@@ -144,9 +169,14 @@ def wip(target_release: Optional[Union[Version, str]] = None, level: WipLevels =
     return wrap_func
 
 
-def module_wip(module_globals: dict, target_release: Optional[Union[Version, str]] = None,
-               level: WipLevels = WipLevels.WARNING, message: Optional[str] = None,
-               prefix_doc: Union[bool, str] = True, mark_attr: bool = True):
+def module_wip(
+    module_globals: dict,
+    target_release: Optional[Union[Version, str]] = None,
+    level: WipLevels = WipLevels.WARNING,
+    message: Optional[str] = None,
+    prefix_doc: Union[bool, str] = True,
+    mark_attr: bool = True
+):
     """Emit the WIP warning/error/info when the module is loaded."""
     if mark_attr:
         module_globals["_wip"] = True
